%
%   This file provides LaTeX document style 'jms' for
%   artciles in Journal Of Mathematical Sciences.
%
%   File version: 1.0
%   Last revision: 26/05/2013
%

%
%   General info
%

\NeedsTeXFormat{LaTeX2e}[1994/12/01]
\ProvidesClass{jms}
\LoadClass[twoside,10pt]{extarticle}

%
%   Packages: general purpose
%

\RequirePackage{inputenc}
\RequirePackage[english]{babel}
\RequirePackage{boxedminipage}
\RequirePackage{indentfirst}
\RequirePackage{afterpage}
\RequirePackage{paralist}
\RequirePackage{url}
\RequirePackage{textcomp}
\RequirePackage{cite}
\RequirePackage{mdwlist}
\RequirePackage{bm}
\RequirePackage{graphicx}
\RequirePackage{float}
\RequirePackage[font=small,labelsep=period,bf]{caption}
\RequirePackage[bookmarksnumbered,pdfborder={0 0 0}]{hyperref}

%\RequirePackage{color}
\newcommand{\colorbox}[2]{#2}

\captionsetup[figure]{name=Fig.}


%
%   Release info
%

\newcommand{\VOLUME}{Vol}
\newcommand{\NUMBER}{Num}
\newcommand{\DAY}{Day}
\newcommand{\MONTH}{Month}
\newcommand{\YEAR}{Year}
\newcommand{\ISSNp}{1072-3374}
\newcommand{\ISSNo}{1573-8795}
\newcommand{\YEARSHORT}{ShortYear}


%
%   Paper, printing area, headers and footers
%

\usepackage[%
    paperheight=11in,%279mm,%
    paperwidth=8.25in,%210mm,%
    %textwidth=174mm,
    textheight=234mm,%
    left=18mm,%
    top=2.5cm,%
    right=18mm,%
    %bottom=1.5cm,%
    headsep=0.3cm,%
    headheight=14pt,%
    footskip=0.5cm]{geometry}

\RequirePackage{fancyhdr}
\renewcommand{\headrulewidth}{0.5pt}
\pagestyle{fancy}       %   Default
\fancyhead[LE,RO]{\thepage}
\fancyfoot{}

\fancypagestyle{titul}{%    %   For title pages
\fancyhead{}%
\lhead{\textit{Journal of Mathematical Sciences, Vol.\,\VOLUME, No.\,\NUMBER, \MONTH, \YEAR}}%
\fancyfoot{}%

\renewcommand{\footrulewidth}{0.0pt}
\fancyfoot[LE,RO]{\thepage}
\cfoot{\ISSNp/\YEARSHORT/\VOLUME\NUMBER-0\arabic{page}\ \textcopyright\ \YEAR\  Springer Science+Business Media New York}%

}

%
%   Section formatting
%

\usepackage[tiny, compact]{titlesec}
\titlelabel{\thetitle.\quad}

%
%   Packages: math and so
%

\RequirePackage{amssymb}
\RequirePackage{amsmath}
\RequirePackage{amsthm}
\RequirePackage{amscd}

%
%   New commands for math
%

\newcommand{\Prob}{\mathsf{{P}}}        			%   Probability
\renewcommand{\P}{\Prob}        				%   Probability
\newcommand{\D}{\mathsf{{D}}}					%   Variance
\newcommand{\Var}{\D}						%   Variance as well
\DeclareMathOperator{\cov}{cov}					%   Covariance
\newcommand{\E}{\mathsf{{E}}}					%   Math. expectation

\newcommand{\R}{\mathbb{R}}               %   Real axis
\newcommand{\Z}{\mathbb{Z}}               %   Integers
\newcommand{\N}{\mathbb{N}}               %   Natural numbers
\newcommand{\C}{\mathbb{C}}               %   Complex numbers

\newcommand{\scalar}[2]{\left<#1,#2\right>}          %   Dot product
\newcommand{\norm}[1]{\left\lVert #1 \right\rVert}   %   Norm

%   Many often-used, but absent in LaTeX objects

\DeclareMathOperator{\const}{const}
\DeclareMathOperator{\conv}{conv}
\DeclareMathOperator{\med}{med}
\DeclareMathOperator{\sgn}{sgn}
\DeclareMathOperator{\tr}{tr}
\DeclareMathOperator{\sh}{sh}
\DeclareMathOperator{\Sh}{Sh}
\DeclareMathOperator{\ch}{ch}
\DeclareMathOperator{\Argmin}{Argmin}
\DeclareMathOperator{\diag}{diag}


\renewcommand{\le}{\leqslant}
\renewcommand{\ge}{\geqslant}

\renewcommand{\leq}{\leqslant}
\renewcommand{\geq}{\geqslant}

%
%   Theorems via AMS package
%

\newtheoremstyle{jmsTheorem}% name of the style to be used
  {3pt}% measure of space to leave above the theorem. E.g.: 3pt
  {3pt}% measure of space to leave below the theorem. E.g.: 3pt
  {\itshape}% name of font to use in the body of the theorem
  {\parindent}% measure of space to indent
  {\bfseries}% name of head font
  {.}% punctuation between head and body
  {.5em}% space after theorem head; " " = normal interword space
  {}

\newtheoremstyle{jmsRemark}% name of the style to be used
  {2pt}% measure of space to leave above the theorem. E.g.: 3pt
  {2pt}% measure of space to leave below the theorem. E.g.: 3pt
  {}% name of font to use in the body of the theorem
  {\parindent}% measure of space to indent
  {\bfseries}% name of head font
  {.}% punctuation between head and body
  {.5em}% space after theorem head; " " = normal interword space
  {}

\newtheoremstyle{jmsDefinition}% name of the style to be used
  {2pt}% measure of space to leave above the theorem. E.g.: 3pt
  {2pt}% measure of space to leave below the theorem. E.g.: 3pt
  {}% name of font to use in the body of the theorem
  {\parindent}% measure of space to indent
  {\bfseries}% name of head font
  {.}% punctuation between head and body
  {.5em}% space after theorem head; " " = normal interword space
  {}

\newtheoremstyle{jmsDotlessTheorem}% name of the style to be used
  {3pt}% measure of space to leave above the theorem. E.g.: 3pt
  {3pt}% measure of space to leave below the theorem. E.g.: 3pt
  {\itshape}% name of font to use in the body of the theorem
  {\parindent}% measure of space to indent
  {\bfseries}% name of head font
  {}% punctuation between head and body
  {.5em}% space after theorem head; " " = normal interword space
  {}

\newtheoremstyle{jmsDotlessDefinition}% name of the style to be used
  {2pt}% measure of space to leave above the theorem. E.g.: 3pt
  {2pt}% measure of space to leave below the theorem. E.g.: 3pt
  {}% name of font to use in the body of the theorem
  {\parindent}% measure of space to indent
  {\bfseries}% name of head font
  {}% punctuation between head and body
  {.5em}% space after theorem head; " " = normal interword space
  {}

\renewenvironment{proof}{{\textbf{Proof.}}}{\par}

\theoremstyle{jmsTheorem}
\newtheorem{theorem}{Theorem}
\newtheorem{lemma}{Lemma}
\newtheorem{corollary}{Corollary}
\newtheorem{proposition}{Proposition}

\theoremstyle{jmsDefinition}
\newtheorem{definition}{Definition}

\theoremstyle{jmsRemark}
\newtheorem{remark}{Remark}

\theoremstyle{jmsDotlessTheorem}
\newtheorem{dtheorem}[theorem]{Theorem}
\newtheorem{dlemma}[lemma]{Lemma}
\newtheorem{dcorollary}[corollary]{Corollary}
\newtheorem{dproposition}[proposition]{Proposition}

\theoremstyle{jmsDotlessDefinition}
\newtheorem{ddefinition}{Definition}

\newenvironment{ctheorem}[1]{\begin{dtheorem}\!\!{\normalfont{#1}.}}{\end{dtheorem}}
\newenvironment{clemma}[1]{\begin{dlemma}\!\!{\normalfont{#1}.}}{\end{dlemma}}

%
%   For commands with many variables
%

\newcommand{\processlist}[3][\relax]{%
  \def\listfinish{#1}%
  \long\def\listact{#2}%
  \processnext#3\listfinish}

\newcommand{\processnext}[1]{%
  \ifx\listfinish#1\empty\else\listact{#1}\expandafter\processnext\fi}

%
%   Semi-automatic author system
%
\newcommand{\authors}{\small}

\newcounter{authorNum}
\setcounter{authorNum}{1}

\newcommand{\addAuthor}[1]{%
\g@addto@macro\authors{\quad $^{\text{\arabic{authorNum}}}$\,#1 \addtocounter{authorNum}{1} \\\phantom{}}%
}

% Non-automatic part :(
\newcommand{\first}{$^1$\,}
\newcommand{\second}{$^2$\,}
\newcommand{\third}{$^3$\,}


\renewcommand{\title}[7]{%                           %   Shapka-generating
%   1. Title
%   2. Authors (for header and table of contents)
%   3. Authors (for titlepage)
%   4. Author-info list
%   5. Abstract
%   6. Release info
%   7. Support
\thispagestyle{titul}
%
%   Arcticle title
%
\pdfbookmark[1]{Abstract}{AbstractReference}
\parbox[l]{0.7\textwidth}{\begin{flushleft}%
                    \noindent{%
			\ifx&#7&% No Grant
				\large\bf \MakeUppercase{#1}
			\else
				\large\bf \MakeUppercase{#1}*
			\fi
			}% noindent 
                \end{flushleft}
}
%
%   Authors
%

{\bf #3}

%
%   Abstract
%

\begin{quote}
\small
#5
\end{quote}

%
%   Appereance commands
%
\fancyhead[LO]{{#1}}
\fancyhead[RE]{{#2}}
\IfFileExists{page}{\input{page}}{}

%
%   Bottom text: author info
%

\begin{figure}[b]
\makebox[\linewidth]{\rule{1in}{0.4pt}\hfill}

\processlist{\addAuthor}{#4}
\authors
\ifx&#7&%
  % #8 is empty
  \vspace{-5.5mm}
\else
  \quad* #7\vspace{-1.5mm}
\fi
%
%   Bottom text: release info
%

\noindent\makebox[\linewidth]{\rule{\textwidth}{0.4pt}}
#6
\end{figure}

}


%
%   For reference commands
%

\renewcommand{\refname}{\begin{center}\textbf{REFERENCES}\end{center}}

\newenvironment{references1}{%
\begin{center}\textbf{REFERENCES}\end{center}\begin{enumerate*}}{\end{enumerate*}}  %   References list

\newcommand{\source}{\item}

\newenvironment{references}%
	{\def\section*{\center\textbf{REFERENCES}}%
	\pdfbookmark[1]{References}{ReferenceToReferences}
	\renewcommand{\refname}{}%
	%\begin{center}\textbf{REFERENCES}\end{center}%
	\begin{thebibliography}{00}}%
        {\end{thebibliography}}

%   No brackets, just number
\makeatletter
\renewcommand\@biblabel[1]{#1.}
\makeatother

%   Shorten the spaces

\let\oldbibliography\thebibliography
\renewcommand{\thebibliography}[1]{%
  \oldbibliography{#1}%
  \setlength{\itemsep}{-1.4pt}%
}

%
%   Duplicate the symbol after the '\HM' command on the next line
%
\newcommand*{\HM}[1]{#1\nobreak\discretionary{}{\hbox{\(\mathsurround=0pt #1\)}}{}}

\newcommand{\No}{\textnumero}

%
%	Page accounting
%
\newcommand{\releaseInfo}{Proceedings of the XXV International Seminar on Stability Problems for Stochastic Models, Maiori (Salerno), Italy, September 20--24, 2005.}
\newcommand{\releaseInfoSec}{Proceedings of the XXIV International Seminar on Stability Problems for Stochastic Models, Jurmala, Latvia, September~10--17, 2004}
\setcounter{page}{1}

%\renewcommand{\baselinestretch}{2}
